/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.fol;

import java.util.List;

import edu.freiburg.dbis.rdd.sparql.SPARQLVariable;

/**
 * Representation of FO \exists construct
 * 
 * @author MSchmidt
 */
public class FOExists extends FOFormula {
	protected List<SPARQLVariable> vars;
	protected FOFormula inner;
	
	public FOExists(List<SPARQLVariable> vars, FOFormula inner) {
		this.vars = vars;
		this.inner = inner;
	}
	
	public String toRIF() {
		StringBuffer buf = new StringBuffer();
		buf.append("Exists ");
		for (SPARQLVariable var : vars) {
			buf.append(var);
			buf.append(" ");
		}
		buf.append("(");
		buf.append(inner.toRIF());
		buf.append(")");
		
		return buf.toString();
	}

	@Override
	public String toFullSPARQL(boolean ask,Integer limit) {
		StringBuffer buf = new StringBuffer();
		buf.append(FOFormula.sparqlQueryPrefix(ask,null));
		buf.append("FILTER NOT EXISTS { ");
		buf.append(toSPARQL(ask));
		buf.append(" } ");
		buf.append(FOFormula.sparqlQuerySuffix(limit));
		return buf.toString();
	}
	
	@Override
	public String toSPARQL(boolean ask) {
		// note that, by default, we assume that the filter is nested
		// inside an implies (which is almost always the case). The case
		// with filter at top-level is handled separately in <tt>toFullSPARQL</tt>.
		return inner.toSPARQL(ask);
	}
}
