/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.fol;

import java.util.LinkedList;
import java.util.List;

/**
 * First-order logic "OR" expression
 * 
 * @author MSchmidt
 */
public class FOOr extends FOFormula {
	protected List<FOFormula> disjunction;
	
	public FOOr(List<FOFormula> disjunction) {
		this.disjunction = disjunction;
	}
	
	@Override
	public String toRIF() {
		StringBuffer buf = new StringBuffer();
		buf.append("Or(");
		int i=0;
		for (FOFormula formula : disjunction) {
			if (i++>0) buf.append(" ");
			buf.append(formula.toRIF());
		}
		buf.append(")");
		
		return buf.toString();
	}
	
	@Override
	public String toSPARQL(boolean ask) {
		List<FOFormula> tripleDisjuncts = getTripleDisjuncts();
		List<FOFormula> filterDisjuncts = getFilterDisjuncts();
		
		StringBuilder buf = new StringBuilder();
		for (int i=0; i<tripleDisjuncts.size(); i++) {
			if (i>0) buf.append(" UNION \n");
			buf.append("{ " + tripleDisjuncts.get(i).toSPARQL(ask) + " } \n");
		}
		
		if (!filterDisjuncts.isEmpty()) {
			if (!tripleDisjuncts.isEmpty())
				buf.append("FILTER (");
			// else: there are no triples, but only datatype restriction (which include a filter anyway)

			for (int i=0; i<filterDisjuncts.size(); i++) {
				if (i>0) buf.append(" || ");
				buf.append(filterDisjuncts.get(i).toSPARQL(ask));
			}

			if (!tripleDisjuncts.isEmpty())
				buf.append(")\n");
			// else: there are no triples, but only datatype restriction (which include a filter anyway)
		}		
		return buf.toString();
	}
	
	public List<FOFormula> getTripleDisjuncts() {
		List<FOFormula> tripleDisjuncts = new LinkedList<FOFormula>();
		for (FOFormula disjunct : disjunction) {
			if (disjunct instanceof FOTriple) {
				tripleDisjuncts.add(disjunct);
			} else if ((disjunct instanceof FOEquals) || 
					(disjunct instanceof FONot)) {
				// ignore
			} else 
				throw new RuntimeException(
					"Case " + disjunct.getClass().getSimpleName() + 
					" not implemented. Aborting in conjunction.");
		}
		
		return tripleDisjuncts;
	}

	public List<FOFormula> getFilterDisjuncts() {
		List<FOFormula> filterDisjuncts = new LinkedList<FOFormula>();
		for (FOFormula disjunct : disjunction) {
			if (disjunct instanceof FOTriple) {
				// ignore
			} else if ((disjunct instanceof FOEquals) || 
					(disjunct instanceof FONot)) {
				filterDisjuncts.add(disjunct);
			} else 
				throw new RuntimeException(
					"Case " + disjunct.getClass().getSimpleName() + 
					" not implemented. Aborting in disjunction.");
		}
		
		return filterDisjuncts;
	}
}