/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.fol;

/**
 * Representation of range type specification in FO
 * 
 * @author MSchmidt
 */
public class FORangeType extends FOFormula {
	
	/**
	 * The underlying relation to associate the elem with.
	 */
	public static enum Relation {
		BNODE,
		IRI,
		LITERAL,
		RESOURCE
	};
	
	protected Relation relation;
	
	protected FOIRIOrSPARQLVariable elem;
	
	/**
	 * @param elem
	 * @param relation
	 */
	public FORangeType(FOIRIOrSPARQLVariable elem, Relation relation) {
		this.elem = elem;
		this.relation = relation;
	}
	
	@Override
	public String toRIF() {
		StringBuffer buf = new StringBuffer();
		buf.append(relation.toString());
		buf.append("(");
		buf.append(elem);
		buf.append(")");
		
		return buf.toString();
	}
	
	@Override
	public String toSPARQL(boolean ask) {
		StringBuilder buf = new StringBuilder();
		switch (relation) {
		case BNODE:
			buf.append("isBlank(" + elem.toString() + ")");
			break;
		case IRI:
			buf.append("isIri(" + elem.toString() + ")");
			break;
		case LITERAL:
			buf.append("isLiteral(" + elem.toString() + ")");
			break;
		case RESOURCE:
			buf.append("(isIri(" + elem.toString() + ") || isBlank(" + elem.toSPARQL() + "))");
			break;
		default:
			// should never happen
			throw new RuntimeException("Illegal case. Aborting.");
		}
		return buf.toString();
	}
}