/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.fol;

import edu.freiburg.dbis.rdd.sparql.IRI;
import edu.freiburg.dbis.rdd.sparql.SPARQLVariable;

/**
 * FO triple representation in first-order logics
 * 
 * @author MSchmidt
 */
public class FOTriple extends FOFormula {
	protected FOIRIOrSPARQLVariable subject;
	protected FOIRIOrSPARQLVariable predicate;
	protected FOIRIOrSPARQLVariable object;	
	
	public FOTriple(FOIRIOrSPARQLVariable subject, FOIRIOrSPARQLVariable predicate, FOIRIOrSPARQLVariable object) {
		this.subject = subject;
		this.predicate = predicate;
		this.object = object;
	}

	public FOTriple(IRI subject, IRI predicate, IRI object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(IRI subject, IRI predicate, SPARQLVariable object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(IRI subject, SPARQLVariable predicate, IRI object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(SPARQLVariable subject, IRI predicate, IRI object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(IRI subject, SPARQLVariable predicate, SPARQLVariable object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(SPARQLVariable subject, IRI predicate, SPARQLVariable object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	public FOTriple(SPARQLVariable subject, SPARQLVariable predicate, IRI object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}
	
	public FOTriple(SPARQLVariable subject, SPARQLVariable predicate, SPARQLVariable object) {
		this.subject = new FOIRIOrSPARQLVariable(subject);
		this.predicate = new FOIRIOrSPARQLVariable(predicate);
		this.object = new FOIRIOrSPARQLVariable(object);
	}

	@Override
	public String toRIF() {
		StringBuffer buf = new StringBuffer();
		buf.append(subject);
		buf.append("[");
		buf.append(predicate);
		buf.append(" -> ");
		buf.append(object);
		buf.append("]");
		
		return buf.toString();
	}
	
	@Override
	public String toSPARQL(boolean ask) {
		StringBuilder buf = new StringBuilder();
		buf.append(subject.toSPARQL() + " ");
		buf.append(predicate.toSPARQL() + " ");
		buf.append(object.toSPARQL());
		return buf.toString();
	}
}