/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.model;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import edu.freiburg.dbis.rdd.fol.FOConstraintBuilder;
import edu.freiburg.dbis.rdd.fol.FOConvertable;
import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.provenance.ConstraintProvenanceStringBuilder;
import edu.freiburg.dbis.rdd.semantics.Environment;
import edu.freiburg.dbis.rdd.sparql.IRI;

/**
 * Representation of a CLASSES constraint section
 * 
 * @author MSchmidt
 */
public class ClassConstraintSec implements FOConvertable {
	protected List<ClassConstraint> ccs;
	protected boolean isOWA;
	
	public ClassConstraintSec(WA worldAssumption, List<ClassConstraint> ccs) {
		isOWA = WA.OWA.equals(worldAssumption);		
		this.ccs = new ArrayList<ClassConstraint>();
		this.ccs.addAll(ccs);
	}
	
	public List<ClassConstraint> getClassConstraints() {
		return ccs;
	}
	
	public boolean isOWA() {
		return isOWA;
	}
	
	@Override
	public String toString() {
		StringBuffer buf = new StringBuffer();
		if (isOWA)
			buf.append("OWA");
		else
			buf.append("CWA");
		buf.append(" CLASSES { \n");
		for (ClassConstraint cc : ccs) {
			buf.append(cc.toString() + "\n\n");
		}
		buf.append("}");
		return buf.toString();
	}

	@Override
	public Set<FOFormula> toFOL(Environment e) {
		Set<FOFormula> ret = new HashSet<FOFormula>();
		
		// STEP 1: collect constraints imposed by individual props
		Set<IRI> clazzez = new HashSet<IRI>();
		for (ClassConstraint cc : ccs) {
			ret.addAll(cc.toFOL(e));
			clazzez.add(cc.getClazz()); // collect class IRIs
		}
		
		// STEP 2: set up WA constraint if section defined CWA
		if (!isOWA)
			ret.addAll(
				FOConstraintBuilder.classCwaConstraint(clazzez,
				ConstraintProvenanceStringBuilder.classCwaConstraint()));
		
		return ret;
	}
}
