/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.model;

import java.util.LinkedList;
import java.util.List;

import edu.freiburg.dbis.rdd.fol.FOConstraintBuilder;
import edu.freiburg.dbis.rdd.fol.FOConvertable;
import edu.freiburg.dbis.rdd.fol.FOConvertableInContext;
import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.provenance.ConstraintProvenanceStringBuilder;
import edu.freiburg.dbis.rdd.semantics.Environment;
import edu.freiburg.dbis.rdd.sparql.IRI;
import edu.freiburg.dbis.rdd.sparql.SPARQLVariableFactory;

/**
 * A property constraint. The class is serializable to a SPARQL query, checking
 * whether the constraints holds or not, through interface {@link FOConvertable}. 
 * 
 * @author MSchmidt
 */
public class PropConstraint implements FOConvertableInContext {
	protected IRIWithRangeType propWithRangeType;
	protected SPARQLVariableFactory svf;
	
	public PropConstraint() {
		this.svf = SPARQLVariableFactory.getInstance();
	}

	public void setPropWithRangeType(IRIWithRangeType propWithRangeType) {
		this.propWithRangeType = propWithRangeType;
	}
		
	public IRIWithRangeType getPropWithRange() {
		return propWithRangeType;
	}
	
	@Override
	public String toString() {
		return propWithRangeType + ";";
	}

	@Override
	public List<FOFormula> toFOL(IRI clazz, Environment e) {
		List<FOFormula> ret = new LinkedList<FOFormula>();		
		if (propWithRangeType.getRangeType()!=null)
			ret.addAll(
				FOConstraintBuilder.rangeTypeConstraint(clazz,propWithRangeType,
				ConstraintProvenanceStringBuilder.rangeTypeConstraint(clazz, this)));

		return ret;		
	}
}
