/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.parser;

import edu.freiburg.dbis.rdd.model.PrefixSec;

/**
 * The prefix manager is a singleton structure
 * to which a prefix section can be registered 
 * and looked up. Within the parsing process,
 * the prefix section is used to properly resolve
 * prefixes encountered in the IRIs.
 * 
 * To this end, the PrefixManager is (re-)initialized
 * always at the beginning of the parsing process.
 * 
 * @author MSchmidt
 */
public class PrefixManager {

	private PrefixSec prefixSec;
	
	private static PrefixManager prefixManager = null;
	
	public static synchronized PrefixManager getInstance() {
		if (prefixManager==null)
			prefixManager = new PrefixManager();
		
		return prefixManager;
	}

	/**
	 * Resets or initializes the {@link PrefixManager}
	 * with an empty prefix section.
	 */
	public void initEmpty() {
		prefixSec = new PrefixSec();
	}
	
	public void setPrefixSec(PrefixSec prefixSec) {
		this.prefixSec = prefixSec;
	}
	
	public PrefixSec getPrefixSec() {
		return prefixSec;
	}
	
	private PrefixManager() {
		initEmpty();
	}
}