/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.provenance;

import org.apache.log4j.Logger;

import edu.freiburg.dbis.rdd.model.DomainConstraint;
import edu.freiburg.dbis.rdd.model.Key;
import edu.freiburg.dbis.rdd.model.MaxConstraint;
import edu.freiburg.dbis.rdd.model.MinConstraint;
import edu.freiburg.dbis.rdd.model.PartialityConstraint;
import edu.freiburg.dbis.rdd.model.PathConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraint;
import edu.freiburg.dbis.rdd.model.RangeConstraint;
import edu.freiburg.dbis.rdd.model.SubPropertyConstraint;
import edu.freiburg.dbis.rdd.model.TotalityConstraint;
import edu.freiburg.dbis.rdd.provenance.ConstraintProvenanceInfo.ConstraintClass;
import edu.freiburg.dbis.rdd.provenance.ConstraintProvenanceInfo.PropConstraintClass;
import edu.freiburg.dbis.rdd.sparql.IRI;

/**
 * Returns strings clarifying the provenance
 * 
 * @author MSchmidt
 */
public class ConstraintProvenanceStringBuilder {
	
	private static Logger logger = Logger.getLogger(ConstraintProvenanceStringBuilder.class);

	public static ConstraintProvenanceInfo rangeTypeConstraint(
			IRI clazz, PropConstraint constraint) {

		ConstraintClass constraintClass = clazz==null? 
				ConstraintClass.UNQUALIFIED_PROPERTY_CONSTRAINT :
				ConstraintClass.QUALIFIED_PROPERTY_CONSTRAINT;
		
		return new ConstraintProvenanceInfo(
			constraint.getPropWithRange().toString(), 
			constraintClass, clazz,PropConstraintClass.RANGE_TYPE_CONSTRAINT);
	}
	
	public static ConstraintProvenanceInfo propertyConstraint(IRI clazz, PropConstraint constraint) {
		
		ConstraintClass constraintClass = clazz==null? 
				ConstraintClass.UNQUALIFIED_PROPERTY_CONSTRAINT :
				ConstraintClass.QUALIFIED_PROPERTY_CONSTRAINT;
		
		PropConstraintClass pcc;
		if (constraint instanceof DomainConstraint) {
			pcc = PropConstraintClass.DOMAIN_CONSTRAINT;
		} else if (constraint instanceof MinConstraint) {
			pcc = PropConstraintClass.MIN_CONSTRAINT;
		} else if (constraint instanceof MaxConstraint) {
			pcc = PropConstraintClass.MAX_CONSTRAINT;
		} else if (constraint instanceof PartialityConstraint) {
			pcc = PropConstraintClass.PARTIALITY_CONSTRAINT;
		} else if (constraint instanceof PathConstraint) {
			pcc = PropConstraintClass.PATH_CONSTRAINT;
		} else if (constraint instanceof RangeConstraint) {
			pcc = PropConstraintClass.RANGE_CONSTRAINT;
		} else if (constraint instanceof SubPropertyConstraint) {
			pcc = PropConstraintClass.SUBPROPERTY_CONSTRAINT;
		} else if (constraint instanceof TotalityConstraint) {
			pcc = PropConstraintClass.TOTALITY_CONSTRAINT;
		} else {
			String msg = "Unknown constraint class for constraint '" + constraint + "'";
			logger.warn(msg);
			throw new RuntimeException(msg);
		}

		return new ConstraintProvenanceInfo(
				constraint.toString(), constraintClass,clazz,pcc);
	}

	public static ConstraintProvenanceInfo propertyCWAConstraint(IRI clazz) {
		
		ConstraintClass constraintClass = clazz==null? 
				ConstraintClass.PROPERTIES_CWA_CONSTRAINT :
				ConstraintClass.CLASS_CWA_CONSTRAINT;
		return new ConstraintProvenanceInfo("",constraintClass,clazz,null);
	}

	public static ConstraintProvenanceInfo classSingletonConstraint(IRI clazz) {
		
		return new ConstraintProvenanceInfo("",
				ConstraintClass.CLASS_SINGLETON_CONSTRAINT,clazz,null);
	}

	public static ConstraintProvenanceInfo classKeyConstraint(IRI clazz, Key key) {
		
		return new ConstraintProvenanceInfo(key.toString(),
				ConstraintClass.CLASS_KEY_CONSTRAINT,clazz,null);
	}

	public static ConstraintProvenanceInfo classCwaConstraint() {

		return new ConstraintProvenanceInfo("",
				ConstraintClass.CLASSES_CWA_CONSTRAINT,null,null);
	}
}