/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.parser;

import edu.freiburg.dbis.rdd.model.ClassConstraint;
import edu.freiburg.dbis.rdd.model.ClassConstraintSec;
import edu.freiburg.dbis.rdd.model.PropConstraint;
import edu.freiburg.dbis.rdd.model.PropConstraintSec;

/**
 * Parser test utility used throughout different tests.
 * 
 * @author MSchmidt
 */
public class Util {

	/**
	 * Checks whether a class constraint section contains a constraint
	 * of the specified type.
	 */
	public static boolean containsConstraint(ClassConstraintSec ccs, Class<?> constraintClazz) {
		for (ClassConstraint cc : ccs.getClassConstraints())
			for (PropConstraint pc : cc.getPropConstraints())
				if (pc.getClass().equals(constraintClazz))
					return true;
		
		return false; // no match
	}
	
	/**
	 * Checks whether a prop constraint section contains a constraint
	 * of the specified type.
	 */
	public static boolean containsConstraint(PropConstraintSec pcs, Class<?> constraintClazz) {
			for (PropConstraint pc : pcs.getPropConstraints())
				if (pc.getClass().equals(constraintClazz))
					return true;
		
		return false; // no match
	}
}