/*
Copyright 2014, Albert-Ludwigs-Universitt Freiburg (Database Group)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package edu.freiburg.dbis.rdd.sparql;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Set;

import org.junit.Test;
import org.openrdf.repository.RepositoryException;
import org.openrdf.rio.RDFFormat;

import edu.freiburg.dbis.rdd.RDDEvaluationResult;
import edu.freiburg.dbis.rdd.RDDExecutor;
import edu.freiburg.dbis.rdd.fol.FOFormula;
import edu.freiburg.dbis.rdd.model.RDD;
import edu.freiburg.dbis.rdd.parser.ParseException;
import edu.freiburg.dbis.rdd.parser.RDDParser;

public class ClassCWATest {

	protected static String TEST_BASE_DIR = "examples/test/sparql/";

	@Test
	public void testClassCWASucceeding() 
	throws ParseException, RepositoryException, IOException {

		String rddFileStr = TEST_BASE_DIR + "ClassCWASucceeding.rdd";
		String dataFileStr = TEST_BASE_DIR + "classcwa.nt";
		FileInputStream fis = new FileInputStream(new File(rddFileStr));
		File dataFile = new File(dataFileStr);
		
	    RDDParser parser = new RDDParser(fis);	    
	    RDD rdd = parser.rdd();

		 Set<FOFormula> formulas = rdd.toFOL();

		 RDDEvaluationResult erAsk =
	    	RDDExecutor.evalResult(formulas, dataFile, RDFFormat.NTRIPLES, true);
		 System.out.println(erAsk);
		 RDDEvaluationResult erSelect =
			RDDExecutor.evalResult(formulas, dataFile, RDFFormat.NTRIPLES, false);
		 System.out.println(erSelect);
		 
		 assertTrue(erAsk.allSucceeded());
		 assertTrue(erSelect.allSucceeded());
	}
	
	@Test
	public void testClassCWAFailing() 
	throws ParseException, RepositoryException, IOException {

		String rddFileStr = TEST_BASE_DIR + "ClassCWAFailing.rdd";
		String dataFileStr = TEST_BASE_DIR + "classcwa.nt";
		FileInputStream fis = new FileInputStream(new File(rddFileStr));
		File dataFile = new File(dataFileStr);
		
	    RDDParser parser = new RDDParser(fis);	    
	    RDD rdd = parser.rdd();

		 Set<FOFormula> formulas = rdd.toFOL();

		 RDDEvaluationResult erAsk =
	    	RDDExecutor.evalResult(formulas, dataFile, RDFFormat.NTRIPLES, true);
		 System.out.println(erAsk);
		 RDDEvaluationResult erSelect =
			RDDExecutor.evalResult(formulas, dataFile, RDFFormat.NTRIPLES, false);
		 System.out.println(erSelect);
		 
		 assertTrue(erAsk.allRddFailed());
		 assertTrue(erSelect.allRddFailed());
	}
}